CHANGES
===============
0.1.0

- test

0.1.2

- first version

0.1.3

- setup bug fix

0.1.4

- 1.complete document
- 2.fix working directory(-d) option bug
- 3.change to use cdnjs static resource

0.1.5

- 1.using **ThreadingHTTPServer** to handle concurrency request
- 2.import **static** resource to avoid the slow speed of cdnjs in China, then the EditOnline size increased >.<
- 3.bind address support, see **-h**
- 4.add EditOnline.py to scripts

0.1.6

- 1.fix libdir bug
- 2.change package info

0.1.7

- 1.wsgi suport


0.1.9

- 1.shell bug

0.1.10

- 1.fix wsgi bug

0.1.11

- 1.short key change
- 2.add toolbar

0.1.12

- 1.fix 401 bug
- 2.short key help
